import axios from "axios"

let token
const TOKEN_KEY = "token"

export const getToken = () => {
    if (token) {
        return token
    }
    if (window) {
        if (!window.sessionStorage.getItem(TOKEN_KEY)) {
            const token = crypto? crypto.randomUUID() : Math.random()
            window.sessionStorage.setItem(TOKEN_KEY, token)
        }
        token = window.sessionStorage.getItem(TOKEN_KEY)
    }
    return token
}

export const applyDiff = (state, diff) => {
    for (const substate in diff) {
        let s = state
        const path = substate.split(".").slice(1)
        while (path.length > 0) {
            s = s[path.shift()]
        }
        for (const key in diff[substate]) {
            s[key] = diff[substate][key]
        }
    }
    return state
}

export const applyEvent = async (state, event, endpoint) => {
    event.token = getToken()
    const diff = (await axios.post(endpoint, event)).data
    return applyDiff(state, diff)
}

export const updateState = async (state, setState, endpoint) => {
    if (state.processing || state.events.length == 0) {
        return
    }
    setState({...state, processing: true})
    await applyEvent(state, state.events.pop(), endpoint)
    setState({
        ...state,
        events: state.events,
        processing: false
    })
}

export const updatePage = (state, router) => {
    if (state.page != "" && state.page != router.pathname) {
        router.push(state.page)
    }
}
