"""A code component."""

import json
from typing import Dict

import black

from pynecone import utils
from pynecone.components.chakra import ChakraComponent
from pynecone.components.library_component import LibraryComponent
from pynecone.components.tag import Tag
from pynecone.property import Property


class Code(LibraryComponent):
    """A code block."""

    library = "react-syntax-highlighter"

    tag = "ReactSyntaxHighlighter"

    # The source code to display.
    text: Property[str]

    # The language to use.
    language: Property[str]

    # If this is enabled line numbers will be shown next to the code block.
    show_line_numbers: Property[bool]

    # The starting line number to use.
    starting_line_number: Property[int]

    # Whether to wrap long lines.
    wrap_long_lines: Property[bool]

    # A custom style for the code block.
    custom_style: Property[Dict[str, str]]

    @classmethod
    def create(cls, code: str, **attrs):
        """Create a text component.

        Args:
            code: The code to display.
            **attrs: The attributes to pass to the component.

        Returns:
            The text component.
        """
        if attrs.get("language") == "python":
            code = black.format_str(code, mode=black.FileMode(line_length=60)).strip()
        return cls(text=code, **attrs)  # type: ignore

    def _render(self) -> Tag:
        return (
            super()._render().set(contents=utils.wrap(json.dumps(str(self.text)), "{"))
        )


class InlineCode(ChakraComponent):
    """Used to display inline code."""

    tag = "Code"
