"""Table components."""

from typing import List

from pynecone.components.chakra import ChakraComponent
from pynecone.property import Property


class DataTable(ChakraComponent):
    """A data table component."""

    tag = "Grid"

    data: Property[List]
    columns: Property[List]

    search: Property[bool]
    sort: Property[bool]
    resizable: Property[bool]
    pagination: Property[bool]


class Table(ChakraComponent):
    """A table component."""

    tag = "Table"


class Thead(Table):
    """A table header component."""

    tag = "Thead"


class Tbody(Table):
    """A table body component."""

    tag = "Tbody"


class Tfoot(Table):
    """A table footer component."""

    tag = "Tfoot"


class Tr(Table):
    """A table row component."""

    tag = "Tr"


class Th(ChakraComponent):
    """A table header cell component."""

    tag = "Th"

    # Aligns the cell content to the right.
    is_numeric: Property[bool]


class Td(ChakraComponent):
    """A table data cell component."""

    tag = "Td"

    # Aligns the cell content to the right.
    is_numeric: Property[bool]


class TableCaption(ChakraComponent):
    """A table caption component."""

    tag = "TableCaption"

    # The placement of the table caption. This sets the `caption-side` CSS attribute.
    placement: Property[str]


class TableContainer(ChakraComponent):
    """The table container component renders a div that wraps the table component."""

    tag = "TableContainer"
