"""Container to stack elements with spacing."""

from typing import List, Union

from pynecone.components.chakra import ChakraComponent
from pynecone.event import EventChain
from pynecone.property import Property


class Accordion(ChakraComponent):
    """The wrapper that uses cloneElement to pass props to AccordionItem children."""

    tag = "Accordion"

    # If true, multiple accordion items can be expanded at once.
    allow_multiple: Property[bool]

    # If true, any expanded accordion item can be collapsed again.
    allow_toggle: Property[bool]

    # The initial index(es) of the expanded accordion item
    default_index: Property[Union[int, List[int]]]

    # The index(es) of the expanded accordion item
    index: Property[Union[int, List[int]]]

    # If true, height animation and transitions will be disabled.
    reduce_motion: Property[bool]

    # The callback invoked when accordion items are expanded or collapsed.
    on_change: EventChain


class AccordionItem(ChakraComponent):
    """A single accordion item."""

    tag = "AccordionItem"

    # A unique id for the accordion item.
    id_: Property[str]

    # If true, the accordion item will be disabled.
    is_disabled: Property[bool]

    # If true, the accordion item will be focusable.
    is_focusable: Property[bool]


class AccordionButton(ChakraComponent):
    """The button that toggles the expand/collapse state of the accordion item. This button must be wrapped in an element with role heading."""

    tag = "AccordionButton"


class AccordionPanel(ChakraComponent):
    """The container for the details to be revealed."""

    tag = "AccordionPanel"


class AccordionIcon(ChakraComponent):
    """A chevron-down icon that rotates based on the expanded/collapsed state."""

    tag = "AccordionIcon"
