"""A checkbox component."""

from typing import Any, Tuple

from pynecone.components.chakra import ChakraComponent
from pynecone.components.mixins import ControlledMixin
from pynecone.event import EventChain
from pynecone.property import Property


class Checkbox(ControlledMixin, ChakraComponent):
    """The Checkbox component is used in forms when a user needs to select multiple values from several options."""

    tag = "Checkbox"

    # Color scheme for checkbox.
    color_scheme: Property[str]

    # "sm" | "md" | "lg"
    size: Property[str]

    # If true, the checkbox will be checked.
    is_checked: Property[bool]

    # If true, the checkbox will be disabled
    is_disabled: Property[bool]

    # If true and is_disabled is passed, the checkbox will remain tabbable but not interactive
    is_focusable: Property[bool]

    # If true, the checkbox will be indeterminate. This only affects the icon shown inside checkbox and does not modify the is_checked property.
    is_indeterminate: Property[bool]

    # If true, the checkbox is marked as invalid. Changes style of unchecked state.
    is_invalid: Property[bool]

    # If true, the checkbox will be readonly
    is_read_only: Property[bool]

    # If true, the checkbox input is marked as required, and required attribute will be added
    is_required: Property[bool]

    # The name of the input field in a checkbox (Useful for form submission).
    name: Property[str]

    # The callback invoked when the checkbox is focused
    on_focus: EventChain

    # The spacing between the checkbox and its label text (0.5rem)
    spacing: Property[str]

    # The function to trigger on change.
    on_change: EventChain

    def _get_controlled_property(self) -> Property:
        return self.is_checked

    def _get_handler_args(self) -> Tuple[Tuple[str, Any], ...]:
        return ((self.is_checked.name, "e.target.checked"),)


class CheckboxGroup(ChakraComponent):
    """A group of checkboxes."""

    tag = "CheckboxGroup"

    # The initial value of the checkbox group
    default_value: Property[str]

    # If true, all wrapped checkbox inputs will be disabled
    is_disabled: Property[bool]

    # If true, input elements will receive checked attribute instead of isChecked. This assumes, you're using native radio inputs
    is_native: Property[bool]

    # The callback fired when any children Checkbox is checked or unchecked
    on_change: EventChain

    # The value of the checkbox group
    value: Property[str]
