"""A button component."""

from typing import Any, Tuple

from pynecone.components.chakra import ChakraComponent
from pynecone.components.mixins import ControlledMixin
from pynecone.components.tag import Tag
from pynecone.event import EventChain
from pynecone.property import Property


class NumberInput(ControlledMixin, ChakraComponent):
    """The wrapper that provides context and logic to the components."""

    tag = "NumberInput"

    # State property to bind the the input.
    value: Property[int]

    # The placeholder text.
    default_value: Property[int]

    # The type of input.
    type_: Property[str] = "text"  # type: ignore

    # If true, the input's value will change based on mouse wheel.
    allow_mouse_wheel: Property[bool]

    # This controls the value update when you blur out of the input. - If true and the value is greater than max, the value will be reset to max - Else, the value remains the same.
    clamped_value_on_blur: Property[bool]

    # The initial value of the counter. Should be less than max and greater than min
    default_value: Property[int]

    # The border color when the input is invalid.
    error_border_color: Property[str]

    # The border color when the input is focused.
    focus_border_color: Property[str]

    # If true, the input will be focused as you increment or decrement the value with the stepper
    focus_input_on_change: Property[bool]

    # Hints at the type of data that might be entered by the user. It also determines the type of keyboard shown to the user on mobile devices ("text" | "search" | "none" | "tel" | "url" | "email" | "numeric" | "decimal")
    input_mode: Property[str]

    # Whether the input should be disabled.
    is_disabled: Property[bool]

    # If true, the input will have `aria-invalid` set to true
    is_invalid: Property[bool]

    # If true, the input will be in readonly mode
    is_read_only: Property[bool]

    # Whether the input is required
    is_required: Property[bool]

    # Whether the pressed key should be allowed in the input. The default behavior is to allow DOM floating point characters defined by /^[Ee0-9+\-.]$/
    is_valid_character: Property[str]

    # This controls the value update behavior in general. - If true and you use the stepper or up/down arrow keys, the value will not exceed the max or go lower than min - If false, the value will be allowed to go out of range.
    keep_within_range: Property[bool]

    # The maximum value of the counter
    max_: Property[int]

    # The minimum value of the counter
    min_: Property[int]

    # "outline" | "filled" | "flushed" | "unstyled"
    variant: Property[str]

    def _get_local_args(self) -> Tuple[str, ...]:
        return ("val",)

    def _get_handler_args(self) -> Tuple[Tuple[str, Any], ...]:
        return ((self.value.name, "val"),)

    def _render(self) -> Tag:
        return (
            super()
            ._render()
            .add_attrs(
                type=self.type_,
            )
        )


class NumberInputField(ChakraComponent):
    """The input field itself."""

    tag = "NumberInputField"


class NumberInputStepper(ChakraComponent):
    """The wrapper for the input's stepper buttons."""

    tag = "NumberInputStepper"


class NumberIncrementStepper(ChakraComponent):
    """The button to increment the value of the input."""

    tag = "NumberIncrementStepper"


class NumberDecrementStepper(ChakraComponent):
    """The button to decrement the value of the input."""

    tag = "NumberDecrementStepper"
