"""A pin input component."""

from typing import Any, Tuple

from pynecone.components.chakra import ChakraComponent
from pynecone.components.tag import Tag
from pynecone.event import EventChain
from pynecone.property import Property


class PinInput(ChakraComponent):
    """The component that provides context to all the pin-input fields."""

    tag = "PinInput"

    # State property to bind the the input.
    value: Property[str]

    # Function called when all inputs have valid values
    on_complete: EventChain

    # If true, the pin input receives focus on mount
    auto_focus: Property[bool]

    # The default value of the pin input
    default_value: Property[str]

    # The border color when the input is invalid.
    error_border_color: Property[str]

    # The border color when the input is focused.
    focus_border_color: Property[str]

    # The top-level id string that will be applied to the input fields. The index of the input will be appended to this top-level id.
    id_: Property[str]

    # If true, the pin input component is put in the disabled state
    is_disabled: Property[bool]

    # If true, the pin input component is put in the invalid state
    is_invalid: Property[bool]

    # If true, focus will move automatically to the next input once filled
    manage_focus: Property[bool]

    # If true, the input's value will be masked just like `type=password`
    mask: Property[bool]

    # The placeholder for the pin input
    placeholder: Property[str]

    # The type of values the pin-input should allow ("number" | "alphanumeric").
    type_: Property[str]

    # "outline" | "flushed" | "filled" | "unstyled"
    variant: Property[str]

    def _get_local_args(self) -> Tuple[str, ...]:
        return ("val",)

    def _get_handler_args(self) -> Tuple[Tuple[str, Any], ...]:
        return ((self.value.name, "val"),)

    def _render(self) -> Tag:
        return (
            super()
            ._render()
            .add_attrs(
                type=self.type_,
            )
        )


class PinInputField(ChakraComponent):
    """The text field that user types in - must be a direct child of PinInput."""

    tag = "PinInputField"
