"""A radio component."""


from typing import Any, Tuple

from pynecone.components.chakra import ChakraComponent
from pynecone.components.mixins import ControlledMixin
from pynecone.components.typography.text import Text
from pynecone.event import EventChain
from pynecone.property import Property


class RadioGroup(ControlledMixin, ChakraComponent):
    """A grouping of individual radio options."""

    tag = "RadioGroup"

    # State property to bind the the input.
    value: Property[int]


class Radio(Text):
    """Radios are used when only one choice may be selected in a series of options."""

    tag = "Radio"

    # Value of button.
    value: Property[int]

    # If true, the radio will be initially checked.
    default_checked: Property[bool]

    # If true, the radio will be checked. You'll need to pass onChange to update its value (since it is now controlled)
    is_checked: Property[bool]

    # If true, the radio will be disabled.
    is_disabled: Property[bool]

    # If true, the radio button will be invalid. This also sets `aria-invalid` to true.
    is_invalid: Property[bool]

    # If true, the radio will be read-only
    is_read_only: Property[bool]

    # If true, the radio button will be required. This also sets `aria-required` to true.
    is_required: Property[bool]
