"""A button component."""

from typing import Any, List, Tuple

from pynecone.components.chakra import ChakraComponent
from pynecone.components.mixins import ControlledMixin
from pynecone.components.tag import Tag
from pynecone.event import EventChain
from pynecone.property import Property


class RangeSlider(ControlledMixin, ChakraComponent):
    """The RangeSlider is a multi thumb slider used to select a range of related values. A common use-case of this component is a price range picker that allows a user to set the minimum and maximum price."""

    tag = "RangeSlider"

    # State property to bind the the input.
    value: Property[List[int]]

    # The default values.
    default_value: Property[List[int]]

    # The type of input.
    type_: Property[str] = "array"  # type: ignore

    # The writing mode ("ltr" | "rtl")
    direction: Property[str]

    # If false, the slider handle will not capture focus when value changes.
    focus_thumb_on_change: Property[bool] = True  # type: ignore

    # If true, the slider will be disabled
    is_disabled: Property[bool]

    # If true, the slider will be in `read-only` state.
    is_read_only: Property[bool]

    # If true, the value will be incremented or decremented in reverse.
    is_reversed: Property[bool]

    # The minimum value of the slider.
    min_: Property[int]

    # The maximum value of the slider.
    max_: Property[int]

    # The minimum distance between slider thumbs. Useful for preventing the thumbs from being too close together.
    min_steps_between_thumbs: Property[int]

    # Function called when the user is done selecting a new value (by dragging or clicking)
    on_changed_end: EventChain

    # Function called when the user starts selecting a new value (by dragging or clicking)
    on_changed_start: EventChain

    def _get_local_args(self) -> Tuple[str, ...]:
        return ("val",)

    def _get_handler_args(self) -> Tuple[Tuple[str, Any], ...]:
        return ((self.value.name, "val"),)

    def _render(self) -> Tag:
        return (
            super()
            ._render()
            .add_attrs(
                default_value=self.default_value
                if self.default_value is not None
                else [20, 80],
                type=self.type_,
            )
        )


class RangeSliderTrack(ChakraComponent):
    """A button component."""

    tag = "RangeSliderTrack"


class RangeSliderFilledTrack(ChakraComponent):
    """A button component."""

    tag = "RangeSliderFilledTrack"


class RangeSliderThumb(ChakraComponent):
    """A button component."""

    tag = "RangeSliderThumb"

    index: Property[int]
