"""A switch component."""
from typing import Callable, Optional

from pynecone.components.chakra import ChakraComponent
from pynecone.components.tag import Tag
from pynecone.event import EventChain, EventSpec
from pynecone.property import BaseProperty, Property


class Switch(ChakraComponent):
    """Togglable switch component."""

    tag = "Switch"

    # If true, the switch will be checked. You'll need to pass onChange to update its value (since it is now controlled)
    is_checked: Property[bool]

    # If true, the switch will be disabled
    is_disabled: Property[bool]

    # If true and isDisabled is passed, the switch will remain tabbable but not interactive
    is_focusable: Property[bool]

    # If true, the switch is marked as invalid. Changes style of unchecked state.
    is_invalid: Property[bool]

    # If true, the switch will be readonly
    is_read_only: Property[bool]

    # If true, the switch will be required
    is_required: Property[bool]

    # The name of the input field in a switch (Useful for form submission).
    name: Property[str]

    # The callback invoked when the switch is focused
    on_focus: EventChain

    # The spacing between the switch and its label text (0.5rem)
    spacing: Property[str]

    # The placeholder text.
    placeholder: Property[str]

    # The function to trigger on change.
    on_change: EventChain
