"""Container to stack elements with spacing."""

from typing import List

from pynecone.components.chakra import ChakraComponent
from pynecone.property import Property


class Grid(ChakraComponent):
    """The main wrapper of th egrid component."""

    tag = "Grid"

    # Shorthand prop for gridAutoColumns
    auto_columns: Property[str]

    # Shorthand prop for gridAutoFlow
    auto_flow: Property[str]

    # Shorthand prop for gridAutoRows
    auto_rows: Property[str]

    # Shorthand prop for gridColumn
    column: Property[str]

    # Shorthand prop for gridRow
    row: Property[str]

    # Shorthand prop for gridTemplateColumns
    template_columns: Property[str]

    # Shorthand prop for gridTemplateRows
    template_rows: Property[str]


class GridItem(ChakraComponent):
    """Used as a child of Grid to control the span, and start positions within the grid."""

    tag = "GridItem"

    # Shorthand prop for gridArea
    area: Property[str]

    # Shorthand prop for gridColumnEnd
    col_end: Property[str]

    # The column number the grid item should start.
    col_start: Property[int]

    # The number of columns the grid item should span.
    col_span: Property[int]

    # Shorthand prop for gridRowEnd
    row_end: Property[str]

    # The row number the grid item should start.
    row_start: Property[int]

    # The number of rows the grid item should span.
    row_span: Property[int]


class ResponsiveGrid(ChakraComponent):
    """The main wrapper of th egrid component."""

    tag = "SimpleGrid"

    # Shorthand prop for gridAutoColumns
    auto_columns: Property[str]

    # Shorthand prop for gridAutoFlow
    auto_flow: Property[str]

    # Shorthand prop for gridAutoRows
    auto_rows: Property[str]

    # Shorthand prop for gridColumn
    column: Property[str]

    # Shorthand prop for gridRow
    row: Property[str]

    # Alist that defines the number of columns for each breakpoint.
    columns: Property[List[int]]

    # The width at which child elements will break into columns. Pass a number for pixel values or a string for any other valid CSS length.
    min_child_width: Property[str]

    # The gap between the grid items
    spacing: Property[str]

    # The column gap between the grid items
    spacing_x: Property[str]

    # The row gap between the grid items
    spacing_y: Property[str]

    # Shorthand prop for gridTemplateAreas
    template_areas: Property[str]

    # Shorthand prop for gridTemplateColumns
    template_columns: Property[str]

    # Shorthand prop for gridTemplateRows
    template_rows: Property[str]
