"""Tooltip components."""

from pynecone.components.chakra import ChakraComponent
from pynecone.event import EventChain
from pynecone.property import Property


class Tooltip(ChakraComponent):
    """A tooltip message to appear."""

    tag = "Tooltip"

    # The padding required to prevent the arrow from reaching the very edge of the popper.
    arrow_padding: Property[int]

    # The color of the arrow shadow.
    arrow_shadow_color: Property[str]

    # Size of the arrow.
    arrow_size: Property[int]

    # Delay (in ms) before hiding the tooltip
    delay: Property[int]

    # If true, the tooltip will hide on click
    close_on_click: Property[bool]

    # If true, the tooltip will hide on pressing Esc key
    close_on_esc: Property[bool]

    # If true, the tooltip will hide while the mouse is down
    close_on_mouse_down: Property[bool]

    # If true, the tooltip will be initially shown
    default_is_open: Property[bool]

    # Theme direction ltr or rtl. Popper's placement will be set accordingly
    direction: Property[str]

    # The distance or margin between the reference and popper. It is used internally to create an offset modifier. NB: If you define offset prop, it'll override the gutter.
    gutter: Property[int]

    # If true, the tooltip will show an arrow tip
    has_arrow: Property[bool]

    # If true, th etooltip with be disabled.
    is_disabled: Property[bool]

    # If true, the tooltip will be open.
    is_open: Property[bool]

    # The label of the tooltip
    label: Property[str]

    # Callback to run when the tooltip hides
    on_close: EventChain

    # Callback to run when the tooltip shows
    on_open: EventChain

    # Delay (in ms) before showing the tooltip
    open_delay: Property[int]

    # The placement of the popper relative to its reference.
    placement: Property[str]

    # If true, the tooltip will wrap its children in a `<span/>` with `tabIndex=0`
    should_wrap_children: Property[bool]
