"""A text component."""
from __future__ import annotations

from typing import Any

from pynecone.components.chakra import ChakraComponent
from pynecone.components.tag import Tag
from pynecone.property import Property


class Text(ChakraComponent):
    """Text component is the used to render text and paragraphs within an interface. It renders a p tag by default."""

    tag = "Text"

    # The text to display.
    text: Property[str]

    # The CSS `text-align` property
    text_align: Property[str]

    # The CSS `text-transform` property
    casing: Property[str]

    # The CSS `text-decoration` property
    decoration: Property[str]

    # Orientation of text. ("horizontal" | "vertical")
    orientation: Property[str]

    # Override the text element. Tpyes are b, strong, i, em, mark, small, del, ins, sub, and sup.
    as_: Property[str]

    @classmethod
    def create(cls, text: Any, **attrs) -> Text:
        """Create a text component.

        Args:
            text: The text to display.
            **attrs: The attributes to pass to the component.

        Returns:
            The text component.
        """
        if not isinstance(text, Property):
            text = Property.create(text)
            text.is_local = True
        return cls(text=text.to(str), **attrs)

    def _render(self) -> Tag:
        return super()._render().set(contents=self.text)
