"""Base Pynecone middelware."""

from abc import ABC
from typing import Optional

from pynecone.base import Base
from pynecone.event import Event
from pynecone.state import State


class Middleware(Base, ABC):
    """Middleware to preprocess and postprocess requests."""

    def preprocess(self, app, state: State, event: Event) -> Optional[State]:
        """Preprocess the event.

        Args:
            app: The app.
            state: The client state.
            event: The event to preprocess.

        Returns:
            An optional state to return.
        """
        return None

    def postprocess(self, app, state: State, event: Event, delta) -> Optional[State]:
        """Postprocess the event.

        Args:
            app: The app.
            state: The client state.
            event: The event to postprocess.
            delta: The delta to postprocess.

        Returns:
            An optional state to return.
        """
        return None
